{
    'name': 'addon 1',
    'summary': 'addon 1 summary',
    'version': '8.0.1.0.0',
    'author': 'ACSONE SA/NV, '
              'Odoo Community Association (OCA)',
    'depends': [
        'account',
    ],
    'license': 'AGPL-3',
    'website': 'https://acsone.eu/',
}
